package com.nisum.employeeservice.service;

import com.nisum.employeeservice.exception.ResourceNotFoundException;
import com.nisum.employeeservice.model.Employee;
import com.nisum.employeeservice.repository.EmployeeRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

@Service
public class EmployeeService {

  @Autowired EmployeeRepository employeeRepository;

  public List<Employee> findAllEmployees() { return employeeRepository.findAll(); }

  public Employee addEmployee(Employee employee) {
    return employeeRepository.save(employee);
  }

  public Optional<Employee> getEmployeeById(Long employeeId) {
    return employeeRepository.findById(employeeId);
  }

  public Employee updateEmployee(Long employeeId, Employee employeeDetails) throws ResourceNotFoundException {
    Employee employee = employeeRepository.findById(employeeId)
            .orElseThrow(() -> new ResourceNotFoundException("Employee not found :(, ID: " + employeeId));

    employee.setFirstName(employeeDetails.getFirstName());
    employee.setLastName(employeeDetails.getLastName());

    return employeeRepository.save(employee);
  }

  public Map<String, Boolean> deleteEmployee(Long employeeId) throws ResourceNotFoundException {
    Employee employee = employeeRepository.findById(employeeId)
            .orElseThrow(() -> new ResourceNotFoundException("Employee not found :(, ID: " + employeeId));

    employeeRepository.delete(employee);

    return new HashMap<String, Boolean>() {{
      put("deleted", Boolean.TRUE);
    }};
  }
}